@@ -714,5 +714,455 @@ def install():
     cv2==4.8.0.76
     matplotlib==3.8.0
     pyro5==5.15
-    mrjob==0.7.4"""
-    return "Package not Installed properly"
\ No newline at end of file
+    mrjob==0.7.4
+    keras==3.2.1
+    neattext==0.1.3"""
+    return "Package not Installed properly"
+
+def house():
+    """import pandas as pd
+import numpy as np
+import seaborn as sns
+import matplotlib.pyplot as plt
+from sklearn.preprocessing import StandardScaler
+from sklearn.model_selection import train_test_split
+from sklearn.linear_model import LinearRegression
+
+data = pd.read_csv('USA_Housing.csv')
+
+data.head()
+
+data.info()
+
+scaler = StandardScaler()
+
+X = data.drop(['Price', 'Address'], axis=1)
+y = data['Price']
+
+X_scaled = scaler.fit_transform(X)
+
+X_train, X_test, y_train, y_test = train_test_split(X_scaled, y, test_size=0.3, random_state=101)
+
+lr = LinearRegression()
+lr.fit(X_train, y_train)
+
+predicted_prices = lr.predict(X_scaled)
+
+data['Actual Price'] = data['Price'] 
+data = data.drop('Price', axis=1) 
+data['Predicted Price'] = predicted_prices
+
+data.head()
+
+plt.figure(figsize=(10, 6))
+sns.scatterplot(x='Actual Price', y='Predicted Price', data=data, alpha=0.5)
+plt.xlabel('Actual Price')
+plt.ylabel('Predicted Price')
+plt.title('Actual vs Predicted House Prices')
+plt.show()"""
+    return "Package not Installed properly"
+
+def mclass():
+    """import tensorflow as tf
+from tensorflow.keras import layers, models
+from tensorflow.keras.datasets import mnist
+from sklearn.metrics import confusion_matrix
+import numpy as np
+import matplotlib.pyplot as plt
+
+(x_train, y_train), (x_test, y_test) = mnist.load_data()
+
+print("Training data shape:", x_train.shape)
+print("Training labels shape:", y_train.shape)
+print("Test data shape:", x_test.shape)
+print("Test labels shape:", y_test.shape)
+
+print("Sample values in training data:")
+print(x_train[0])
+
+# Normalize pixel values to be between 0 and 1
+x_train, x_test = x_train / 255.0, x_test / 255.0
+
+# Add a channel dimension (for CNN input)
+x_train = np.expand_dims(x_train, axis=-1)
+x_test = np.expand_dims(x_test, axis=-1)
+
+# Convert labels to one-hot encoding
+y_train = tf.keras.utils.to_categorical(y_train, 10)
+y_test = tf.keras.utils.to_categorical(y_test, 10)
+
+model = models.Sequential()
+model.add(layers.Conv2D(32, (3, 3), activation='relu', input_shape=(28, 28, 1)))
+model.add(layers.MaxPooling2D((2, 2)))
+model.add(layers.Conv2D(64, (3, 3), activation='relu'))
+model.add(layers.MaxPooling2D((2, 2)))
+model.add(layers.Conv2D(64, (3, 3), activation='relu'))
+model.add(layers.Flatten())
+model.add(layers.Dense(64, activation='relu'))
+model.add(layers.Dense(10, activation='softmax'))
+
+model.compile(optimizer='adam',
+              loss='categorical_crossentropy',
+              metrics=['accuracy'])
+
+model.fit(x_train, y_train, epochs=5, validation_data=(x_test, y_test))
+
+predictions = np.argmax(model.predict(x_test), axis=1)
+true_labels = np.argmax(y_test, axis=1)
+
+conf_matrix = confusion_matrix(true_labels, predictions)
+print("Confusion Matrix:")
+print(conf_matrix)
+
+# Display an example confusion matrix plot
+plt.imshow(conf_matrix, interpolation='nearest', cmap=plt.cm.Blues)
+plt.title('Confusion Matrix')
+plt.colorbar()
+plt.xlabel('Predicted Label')
+plt.ylabel('True Label')
+plt.show()
+"""
+    return "Package not Installed properly"
+
+def rnn():
+    """from tensorflow.keras.layers import SimpleRNN, LSTM, GRU, Bidirectional, Dense, Embedding
+from tensorflow.keras.datasets import imdb
+from tensorflow.keras.models import Sequential
+import numpy as np
+# Getting reviews with words that come under 5000
+# most occurring words in the entire
+# corpus of textual review data
+vocab_size = 5000
+(x_train, y_train), (x_test, y_test) = imdb.load_data(num_words=vocab_size)
+
+print(x_train[0])
+# Getting all the words from word_index dictionary
+word_idx = imdb.get_word_index()
+
+# Originally the index number of a value and not a key,
+# hence converting the index as key and the words as values
+word_idx = {i: word for word, i in word_idx.items()}
+
+# again printing the review
+print([word_idx[i] for i in x_train[0]])
+# Get the minimum and the maximum length of reviews
+print("Max length of a review:: ", len(max((x_train+x_test), key=len)))
+print("Min length of a review:: ", len(min((x_train+x_test), key=len)))
+from tensorflow.keras.preprocessing import sequence
+
+# Keeping a fixed length of all reviews to max 400 words
+max_words = 400
+
+x_train = sequence.pad_sequences(x_train, maxlen=max_words)
+x_test = sequence.pad_sequences(x_test, maxlen=max_words)
+
+x_valid, y_valid = x_train[:64], y_train[:64]
+x_train_, y_train_ = x_train[64:], y_train[64:]
+# fixing every word's embedding size to be 32
+embd_len = 32
+
+# Creating a RNN model
+RNN_model = Sequential(name="Simple_RNN")
+RNN_model.add(Embedding(vocab_size,
+						embd_len,
+						input_length=max_words))
+
+# In case of a stacked(more than one layer of RNN)
+# use return_sequences=True
+RNN_model.add(SimpleRNN(128,
+						activation='tanh',
+						return_sequences=False))
+RNN_model.add(Dense(1, activation='sigmoid'))
+
+# printing model summary
+print(RNN_model.summary())
+
+# Compiling model
+RNN_model.compile(
+	loss="binary_crossentropy",
+	optimizer='adam',
+	metrics=['accuracy']
+)
+
+# Training the model
+history = RNN_model.fit(x_train_, y_train_,
+						batch_size=64,
+						epochs=5,
+						verbose=1,
+						validation_data=(x_valid, y_valid))
+
+# Printing model score on test data
+print()
+print("Simple_RNN Score---> ", RNN_model.evaluate(x_test, y_test, verbose=0))
+RNN_model.predict(x_test[0:1])"""
+    return "Package not Installed properly"
+
+def brain():
+    """from keras.models import load_model
+import tensorflow as tf
+import cv2
+from tensorflow.keras.preprocessing import image
+import matplotlib.pyplot as plt
+import numpy as np
+labels = ['glioma_tumor','meningioma_tumor','no_tumor','pituitary_tumor']
+
+model = load_model('braintumor.h5')
+
+def brain_tumor(img,):
+    img = cv2.resize(img,(150,150))
+    img_array = np.array(img)
+    img_array = img_array.reshape(1,150,150,3)
+    # img_array.shape
+    with tf.device('/cpu:0'):
+        a=model.predict(img_array, verbose=False)
+    indices = a.argmax()
+    return [labels[indices]]
+
+if __name__ == '__main__':
+#     img = image.load_img('input/testing/pituitary_tumor/image(15).jpg')
+    img = cv2.imread('input/Testing/pituitary_tumor/image(15).jpg')
+    plt.imshow(img)
+    plt.show()
+    print(brain_tumor(img))"""
+    return "Package not Installed properly"
+
+def dcgan():
+    """import tensorflow as tf
+from tensorflow.keras.datasets import mnist
+from tensorflow.keras.layers import Conv2D, Conv2DTranspose, Dense, Flatten, Reshape, LeakyReLU
+from tensorflow.keras.models import Model
+from tensorflow.keras.optimizers import Adam
+import numpy as np
+import matplotlib.pyplot as plt
+
+# Hyperparameters
+latent_dim = 100  # Dimension of random noise input
+image_size = 28  # Size of MNIST images (28x28 pixels)
+num_epochs = 5
+batch_size = 128
+
+def create_generator():
+    model = tf.keras.Sequential()
+    model.add(Dense(7 * 7 * 256, use_bias=False, input_shape=(latent_dim,)))
+    model.add(Reshape((7, 7, 256)))
+    model.add(Conv2DTranspose(128, (3, 3), strides=2, padding='same', activation='relu'))
+    model.add(Conv2DTranspose(64, (3, 3), strides=2, padding='same', activation='relu'))
+    model.add(Conv2DTranspose(1, (3, 3), activation='tanh', padding='same'))
+    return model
+
+def create_discriminator():
+    model = tf.keras.Sequential()
+    model.add(Conv2D(64, (3, 3), strides=2, padding='same', input_shape=(image_size, image_size, 1)))
+    model.add(LeakyReLU(alpha=0.2))  
+    model.add(Conv2D(128, (3, 3), strides=2, padding='same'))
+    model.add(LeakyReLU(alpha=0.2))
+    model.add(Conv2D(256, (3, 3), strides=2, padding='same'))
+    model.add(LeakyReLU(alpha=0.2))
+    model.add(Flatten())
+    model.add(Dense(1, activation='sigmoid'))
+    return model
+
+def create_gan(generator, discriminator):
+    discriminator.compile(loss='binary_crossentropy', optimizer=Adam(learning_rate=0.0002, beta_1=0.5))
+    discriminator.trainable = False  
+
+    gan_input = tf.keras.Input(shape=(latent_dim,))
+    generated_image = generator(gan_input)
+    gan_output = discriminator(generated_image)
+
+    gan_model = Model(inputs=gan_input, outputs=gan_output)
+    gan_model.compile(loss='binary_crossentropy', optimizer=Adam(learning_rate=0.0002, beta_1=0.5))
+    return gan_model
+
+def train_gan(generator, discriminator, gan_model, dataset, epochs, batch_size, latent_dim):
+    for epoch in range(epochs):
+        for batch in range(dataset.shape[0] // batch_size):
+            # Train discriminator
+            noise = tf.random.normal(shape=(batch_size, latent_dim))
+            fake_images = generator.predict(noise)
+            real_images = dataset[np.random.randint(0, dataset.shape[0], batch_size)]
+
+            combined_images = np.concatenate([real_images, fake_images])
+            labels = np.concatenate([np.ones((batch_size, 1)), np.zeros((batch_size, 1))])
+            labels += 0.05 * np.random.random(labels.shape)
+
+            discriminator_loss = discriminator.train_on_batch(combined_images, labels)
+
+            # Train generator
+            noise = tf.random.normal(shape=(batch_size, latent_dim))
+            misleading_targets = np.ones((batch_size, 1))
+
+            generator_loss = gan_model.train_on_batch(noise, misleading_targets)
+
+        print(f'Epoch {epoch + 1}, Discriminator Loss: {discriminator_loss}, Generator Loss: {generator_loss}')
+
+def plot_generated_images(generator, latent_dim, examples=10, figsize=(10, 10)):
+    noise = np.random.normal(0, 1, size=[examples, latent_dim])
+    generated_images = generator.predict(noise)
+    plt.figure(figsize=figsize)
+    for i in range(examples):
+        plt.subplot(1, examples, i+1)
+        plt.imshow(generated_images[i, :, :, 0], cmap='gray')
+        plt.axis('off')
+    plt.tight_layout()
+    plt.show()
+
+# Load MNIST dataset
+(train_images, _), (_, _) = mnist.load_data()
+train_images = train_images.reshape(-1, image_size, image_size, 1)
+train_images = train_images.astype('float32') / 255.0
+
+# Create models
+generator = create_generator()
+discriminator = create_discriminator()
+gan_model = create_gan(generator, discriminator)
+print('created')
+# Train GAN
+train_gan(generator, discriminator, gan_model, train_images, num_epochs, batch_size, latent_dim)
+print('trained')
+# Display generated images
+plot_generated_images(generator, latent_dim)
+"""
+    return "Package not Installed properly"
+
+def classify():
+    """import numpy as np
+import pickle
+import pandas as pd
+from sklearn.feature_extraction.text import CountVectorizer
+from sklearn.model_selection import train_test_split
+from sklearn.naive_bayes import MultinomialNB
+
+try:
+    spamdf = pd.read_csv("spam.csv")
+except:
+    spamdf = pd.read_csv("AImodels\\spam_detection\\spam.csv")
+    
+spamdf['spam'] = spamdf['Category'].apply(lambda x: 1 if x=='spam' else 0)
+x_train, x_test, y_train, y_test = train_test_split(spamdf.Message,spamdf.spam, test_size=0.2)
+
+cv = CountVectorizer()
+x_train_valid = cv.fit_transform(x_train.values)
+
+model = MultinomialNB()
+model.fit(x_train_valid, y_train)
+
+def spam_detection(text):
+    text = cv.transform(text)
+    res = model.predict(text)
+    if res == 0:
+        return ["Not Spam"]
+    else: return ["Spam"]
+
+if __name__ == "__main__":
+    print(spam_detection(['3421452465 call here for reward']))
+"""
+    return "Package not Installed properly"
+
+def btrain():
+    """import keras
+from keras.models import Sequential
+from keras.layers import Conv2D,Flatten,Dense,MaxPooling2D,Dropout
+from sklearn.metrics import accuracy_score
+
+import ipywidgets as widgets
+import io
+from PIL import Image
+import tqdm
+from sklearn.model_selection import train_test_split
+import cv2
+from sklearn.utils import shuffle
+import tensorflow as tf
+
+
+X_train = []
+Y_train = []
+image_size = 150
+labels = ['glioma_tumor','meningioma_tumor','no_tumor','pituitary_tumor']
+for i in labels:
+    folderPath = os.path.join('input/Training',i)
+    for j in os.listdir(folderPath):
+        img = cv2.imread(os.path.join(folderPath,j))
+        img = cv2.resize(img,(image_size,image_size))
+        X_train.append(img)
+        Y_train.append(i)
+
+for i in labels:
+    folderPath = os.path.join('input/Testing',i)
+    for j in os.listdir(folderPath):
+        img = cv2.imread(os.path.join(folderPath,j))
+        img = cv2.resize(img,(image_size,image_size))
+        X_train.append(img)
+        Y_train.append(i)
+
+X_train = np.array(X_train)
+Y_train = np.array(Y_train)
+
+X_train,Y_train = shuffle(X_train,Y_train,random_state=101)
+X_train.shape
+
+
+X_train,X_test,y_train,y_test = train_test_split(X_train,Y_train,test_size=0.1,random_state=101)
+
+y_train_new = []
+for i in y_train:
+    y_train_new.append(labels.index(i))
+y_train=y_train_new
+y_train = tf.keras.utils.to_categorical(y_train)
+
+y_test_new = []
+for i in y_test:
+    y_test_new.append(labels.index(i))
+y_test=y_test_new
+y_test = tf.keras.utils.to_categorical(y_test)
+
+
+model = Sequential()
+model.add(Conv2D(32,(3,3),activation = 'relu',input_shape=(150,150,3)))
+model.add(Conv2D(64,(3,3),activation='relu'))
+model.add(MaxPooling2D(2,2))
+model.add(Dropout(0.3))
+model.add(Conv2D(64,(3,3),activation='relu'))
+model.add(Conv2D(64,(3,3),activation='relu'))
+model.add(Dropout(0.3))
+model.add(MaxPooling2D(2,2))
+model.add(Dropout(0.3))
+model.add(Conv2D(128,(3,3),activation='relu'))
+model.add(Conv2D(128,(3,3),activation='relu'))
+model.add(Conv2D(128,(3,3),activation='relu'))
+model.add(MaxPooling2D(2,2))
+model.add(Dropout(0.3))
+model.add(Conv2D(128,(3,3),activation='relu'))
+model.add(Conv2D(256,(3,3),activation='relu'))
+model.add(MaxPooling2D(2,2))
+model.add(Dropout(0.3))
+model.add(Flatten())
+model.add(Dense(512,activation = 'relu'))
+model.add(Dense(512,activation = 'relu'))
+model.add(Dropout(0.3))
+model.add(Dense(4,activation='softmax'))
+
+model.summary()
+
+model.compile(loss='categorical_crossentropy',optimizer='Adam',metrics=['accuracy'])
+
+history = model.fit(X_train,y_train,epochs=20,validation_split=0.1)
+model.save('braintumor.h5')"""
+
+    return "Package not Installed properly"
+
+excel = """Clean columns - Manager names (TRIM[col]), Quantity (ROUNDUP[col, 0])
+Remove Duplicates - Data Tools
+Data Analysis - File -> Options -> Addins -> Analysis Toolpak -> GO -> Analysis Toolpak
+Data Analysis - Descriptive Stats (Price, Quantity)
+Visualize - Select Price col -> Charts -> Wisker plot ->Select Data -> Horizontal -> Select Managers Col
+Create New Col - Revenue = Quan * Price
+Pivot Table"""
+
+etl = """1. Removed unnessary columns from the products table (we kept productid, productname, qtyperunit, unitinstock)
+2. Changed the data type of unitsinstock from decimal to whole nos.
+3. Expanded the order details table.
+4. Calculated the line total for each order details row. 
+5. Renamed the lineTotal column to Stock Value and shifted its position.
+6. Combined the products and total sales queries"""
+
